Installation — django-nomad-notifier 1.0.1 documentation

### Navigation

- index
- next |
- previous |
- django-nomad-notifier 1.0.1 documentation »

# Installation

## Dependencies

- django-model-utils: https://github.com/carljm/django-model-utils/

## Initial setup

The package is listed in the Python Package Index. You can use your favorite package manager like `easy_install` or `pip`:

    pip install django-nomad-notifier

Or, you can clone the latest development code from its repository and add the folder to your python path. For example, if you use virtualenvwrapper:

    git clone git@github.com:Nomadblue/django-nomad-notifier.git
    add2virtualenv django-nomad-notifier/

Add `notifier` to the `INSTALLED_APPS` setting of your `settings.py`:

    INSTALLED_APPS = (
        ...
        'notifier',
    )

This app uses South migrations to nicely update your database with the `Notification` model schema:

    python manage.py migrate notifier

Otherwise you can go on yourself and sync with Django command:

    python manage.py syncdb

### Navigation

- index
- next |
- previous |
- django-nomad-notifier 1.0.1 documentation »